require 'test_helper'

class TestUser < Minitest::Test
  def setup
  end

  def before_each
  end

  def after_each
  end

  def test_print_file_not_found
    ZmLdifExport.run({ldif_file: '/tmp/xxx'})
    out, _err = capture_io do
      ZmLdifExport.ldif_file
    end
    assert(out == "File /tmp/xxx not found\n", 'No help message')
  end

  def test_print_file_not_valid
    ZmLdifExport.run({ldif_file: '/etc/resolv.conf'})
    out, _err = capture_io do
      ZmLdifExport.load_ldif
    end
    assert(out == "File /etc/resolv.conf not a valid LDIF file\n", 'No help message')
  end

  def test_mk_command_should_start_with_a_comment
    expected_result = '# zmprov createAccount me@example.com'
    actual_result = ZmLdifExport.mk_command(command: 'createAccount', resource: 'me@example.com')
    assert_equal(expected_result, actual_result.split("\n").first)
  end

  def test_mk_command_should_return_one_attribute_by_line
    expected_result = "# zmprov cd example.com\n"
    expected_result << "zmprov cd example.com \\\n"
    expected_result << "cn cn \\\n"
    expected_result << "sn sn \\\n"
    expected_result << "email 1 \\\n"
    expected_result << "email 3"
    
    attributes = {
      'cn': 'cn',
      'sn': 'sn',
      'email': ['1', '3']
    }

    actual_result = ZmLdifExport.mk_command(
      command: 'cd', resource: 'example.com', attributes: attributes
    )
    assert_equal(expected_result, actual_result)
  end

  def test_mk_command_should_return_not_Full_command
    expected_result = "# zmprov createAccount me@example.com\n"
    expected_result << "createAccount me@example.com"
    actual_result = ZmLdifExport.mk_command(command: 'createAccount', resource: 'me@example.com', full: false)
    assert_equal(expected_result, actual_result)
  end

end